@@ -233,11 +233,13 @@ sub option {
 }
 
 sub sanity {
-    my $repo = shift;
+    my ($repo, $patt) = @_;
+    $patt ||= $REPOPATT_PATT;
 
-    _die "invalid repo '$repo'" if not( $repo and $repo =~ $REPOPATT_PATT );
-    _die "'$repo' ends with a '/'" if $repo =~ m(/$);
-    _die "'$repo' contains '..'" if $repo =~ $REPONAME_PATT and $repo =~ m(\.\.);
+    _die "invalid repo '$repo'" if not( $repo and $repo =~ $patt );
+    _die "'$repo' ends with a '/'"  if $repo =~ m(/$);
+    _die "'$repo' contains '..'"    if $repo =~ $REPONAME_PATT and $repo =~ m(\.\.);
+    _die "'$repo' contains '.git/'" if $repo =~ $REPONAME_PATT and $repo =~ m(\.git/);
 }
 
 sub repo_missing {
